# DtoGroundTruthReq


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**datasets** | **List[str]** |  | 

## Example

```python
from rcabench.openapi.models.dto_ground_truth_req import DtoGroundTruthReq

# TODO update the JSON string below
json = "{}"
# create an instance of DtoGroundTruthReq from a JSON string
dto_ground_truth_req_instance = DtoGroundTruthReq.from_json(json)
# print the JSON string representation of the object
print(DtoGroundTruthReq.to_json())

# convert the object into a dict
dto_ground_truth_req_dict = dto_ground_truth_req_instance.to_dict()
# create an instance of DtoGroundTruthReq from a dict
dto_ground_truth_req_from_dict = DtoGroundTruthReq.from_dict(dto_ground_truth_req_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


